Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(292)

Unified Diff: ppapi/c/dev/ppb_websocket_dev.h

Issue 8572009: WebSocket Pepper API documents minor revision (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: addressed reviewed point Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/api/dev/ppb_websocket_dev.idl ('k') | ppapi/cpp/dev/websocket_dev.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/dev/ppb_websocket_dev.h
diff --git a/ppapi/c/dev/ppb_websocket_dev.h b/ppapi/c/dev/ppb_websocket_dev.h
index 2be0c76fb2cca3dc9c613655020d8c986f8eeb7e..0e54db1b341075af4779aac20188cc466862d202 100644
--- a/ppapi/c/dev/ppb_websocket_dev.h
+++ b/ppapi/c/dev/ppb_websocket_dev.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* From dev/ppb_websocket_dev.idl modified Mon Nov 7 15:21:42 2011. */
+/* From dev/ppb_websocket_dev.idl modified Wed Nov 16 02:46:08 2011. */
#ifndef PPAPI_C_DEV_PPB_WEBSOCKET_DEV_H_
#define PPAPI_C_DEV_PPB_WEBSOCKET_DEV_H_
@@ -36,6 +36,10 @@
*/
typedef enum {
/**
+ * Ready state is queried on an invalid resource.
+ */
+ PP_WEBSOCKETREADYSTATE_INVALID_DEV = -1,
+ /**
* Ready state that the connection has not yet been established.
*/
PP_WEBSOCKETREADYSTATE_CONNECTING_DEV = 0,
@@ -243,9 +247,9 @@ struct PPB_WebSocket_Dev {
* @param[in] web_socket A <code>PP_Resource</code> corresponding to a
* WebSocket.
*
- * @return Returns a <code>PP_VARTYPE_NULL</code> var if called before the
- * close reason is set, or <code>PP_VARTYPE_UNDEFINED</code> if called on an
- * invalid resource.
+ * @return Returns a <code>PP_VARTYPE_STRING</code> var. if called before the
+ * close reason is set, its data is empty string. Returns a
+ * <code>PP_VARTYPE_UNDEFINED</code> if called on an invalid resource.
*/
struct PP_Var (*GetCloseReason)(PP_Resource web_socket);
/**
@@ -256,9 +260,9 @@ struct PPB_WebSocket_Dev {
* WebSocket.
*
* @return Returns <code>PP_FALSE</code> if called before the connection is
* closed. Otherwise, returns <code>PP_TRUE</code> if the connection was
* closed cleanly and returns <code>PP_FALSE</code> if the connection was
* closed by abnormal reasons.
*/
PP_Bool (*GetCloseWasClean)(PP_Resource web_socket);
/**
@@ -269,9 +273,9 @@ struct PPB_WebSocket_Dev {
* WebSocket.
*
* @return Returns a <code>PP_VARTYPE_STRING</code> var. If called before the
- * connection is established or called on an invalid resource, its data is
- * empty string.
- * Currently its data is always empty string.
+ * connection is established, its data is empty string. Returns a
+ * <code>PP_VARTYPE_UNDEFINED</code> if called on an invalid resource.
+ * Currently its data for valid resources are always empty string.
*/
struct PP_Var (*GetExtensions)(PP_Resource web_socket);
/**
@@ -282,8 +286,8 @@ struct PPB_WebSocket_Dev {
* WebSocket.
*
* @return Returns a <code>PP_VARTYPE_STRING</code> var. If called before the
- * connection is established, or called on an invalid resource, its data is
- * empty string.
+ * connection is established, its data is empty string. Returns a
+ * <code>PP_VARTYPE_UNDEFINED</code> if called on an invalid resource.
*/
struct PP_Var (*GetProtocol)(PP_Resource web_socket);
/**
@@ -293,8 +297,8 @@ struct PPB_WebSocket_Dev {
* @param[in] web_socket A <code>PP_Resource</code> corresponding to a
* WebSocket.
*
- * @return Returns <code>PP_WEBSOCKETREADYSTATE_CONNECTING</code> if called
- * before the connection is established.
+ * @return Returns <code>PP_WEBSOCKETREADYSTATE_INVALID_DEV</code> if called
+ * before connect() is called, or called on an invalid resource.
*/
PP_WebSocketReadyState_Dev (*GetReadyState)(PP_Resource web_socket);
/**
@@ -304,8 +308,8 @@ struct PPB_WebSocket_Dev {
* WebSocket.
*
* @return Returns a <code>PP_VARTYPE_STRING</code> var. If called before the
- * connection is established, or called on an invalid resource, its data is
- * empty string.
+ * connection is established, its data is empty string. Return a
+ * <code>PP_VARTYPE_UNDEFINED</code> if called on an invalid resource.
*/
struct PP_Var (*GetURL)(PP_Resource web_socket);
};
@@ -256,9 +260,9 @@ struct PPB_WebSocket_Dev {
*
* @return Returns <code>PP_FALSE</code> if called before the connection is
- * closed. Otherwise, returns <code>PP_TRUE</code> if the connection was
- * closed cleanly and returns <code>PP_FALSE</code> if the connection was
- * closed by abnormal reasons.
+ * closed, or called on an invalid resource. Otherwise, returns
+ * <code>PP_TRUE</code> if the connection was closed cleanly, or returns
+ * <code>PP_FALSE</code> if the connection was closed by abnormal reasons.
*/
PP_Bool (*GetCloseWasClean)(PP_Resource web_socket);
« no previous file with comments | « ppapi/api/dev/ppb_websocket_dev.idl ('k') | ppapi/cpp/dev/websocket_dev.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698